@@ -43,11 +43,11 @@ Net::Plurk - A perl interface to Plurk API
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,7 @@ Perhaps a little code snippet.
     my $key = $CONSUMER_KEY;
     my $secret = $CONSUMER_SECRET;
     my $access_token = $ACCESS_TOKEN
-    my $access_secret = $ACCESS_TOKEN_SECRET 
+    my $access_secret = $ACCESS_TOKEN_SECRET
     my $p = Net::Plurk->new(consumer_key => $key, consumer_secret => $secret);
     my $p->authorize(access_token => $access_token,
 	access_token_secret => $access_secret)
@@ -153,7 +153,7 @@ sub callAPI {
 
 given nick_name, return unique_id
 
-=cut 
+=cut
 
 sub _get_unique_id {
     my ($self, $nick_name) = @_;
@@ -162,6 +162,23 @@ sub _get_unique_id {
     return $self->publicProfiles->{$nick_name}->{user_info}->id;
 }
 
+=head2 get_nick_name
+
+given unique_id, return nick_name
+
+=cut
+
+sub get_nick_name {
+    my ($self, $id) = @_;
+
+    $self->get_own_profile() unless $self->own_profile;
+    return $self->own_profile->nick_name
+	if $self->own_profile->{user_info}->{id} eq $id;
+
+    my $profile = $self->get_public_profile($id);
+    return $profile->nick_name;
+}
+
 =head2 get_public_profile
 
 call /Profile/getPublicProfile
@@ -199,7 +216,7 @@ sub get_own_profile {
 
 call /Polling/getPlurks
 arguments =>
-    offset: Return plurks newer than offset, formatted as 2009-6-20T21:55:34. 
+    offset: Return plurks newer than offset, formatted as 2009-6-20T21:55:34.
 
 =cut
 
@@ -299,6 +316,27 @@ sub add_plurk {
     return ;
 }
 
+=head2 get_plurk
+
+    get_plurk ($plurk_id)
+    $plurk_id can be base 36 encoded, or not
+
+=cut
+
+sub get_plurk {
+    my ($self, $plurk_id) = @_;
+    use Math::Base36 ':all';
+    $plurk_id = decode_base36($plurk_id) unless $plurk_id =~ m/^\d+$/m;
+    my $json_data = $self->callAPI(
+        '/Timeline/getPlurk',
+        plurk_id => $plurk_id,
+    );
+    return $json_data if $self->raw_output;
+    # XXX: didn't handle $json_data->{user}
+    return Net::Plurk::Plurk->new($json_data->{plurk}) if !$self->errormsg;
+    return ;
+}
+
 =head1 AUTHOR
 
 Cheng-Lung Sung, C<< <clsung at cpan.org> >>
