@@ -12,7 +12,6 @@ Foobar
 =cut
 
 has 'id' => (is => 'rw', isa => 'Int');
-has 'uid' => (is => 'rw', isa => 'Int');
 has 'has_profile_image' => (is => 'rw', isa => 'Int');
 has 'avatar' => (is => 'rw', isa => 'Maybe[Int]');
 # not_saying, single, married, divorced, engaged, in_relationship, complicated, widowed, open_relationship
@@ -26,6 +25,8 @@ has 'date_of_birth' => (is => 'rw', isa => 'Maybe[Str]');
 has 'karma' => (is => 'rw', isa => 'Num', default => 0);
 has 'gender' => (is => 'rw', isa => 'Int');
 has 'recruited' => (is => 'rw', isa => 'Int');
+has 'is_premium' => (is => 'ro', isa => 'Maybe[Object]', default => 'JSON::false');
+has 'email_confirmed' => (is => 'ro', isa => 'Maybe[Object]', default => 'JSON::false');
 
 sub _build_display_name {
     my $self = shift;
